tic4x_scan: match printable arch string

Alan Modra amodra@gmail.com
Thu Oct 30 23:31:33 GMT 2025


Fix odd behaviour of objcopy -I -B on tic4x, where the tms320c4x
string reported by objcopy --info isn't a valid arch string.

	* cpu-tic4x.c (tic4x_scan): Match arch string reported by
	objcopy --info.

diff --git a/bfd/cpu-tic4x.c b/bfd/cpu-tic4x.c
index e154b8fa3f0..88f0e857062 100644
--- a/bfd/cpu-tic4x.c
+++ b/bfd/cpu-tic4x.c
@@ -28,10 +28,12 @@ static bool
 tic4x_scan (const struct bfd_arch_info *info,
 	    const char *string)
 {
   /* Allow strings of form [ti][Cc][34], let's not be too picky
      about strange numbered machines in C3x or C4x series.  */
   if (string[0] == 't' && string[1] == 'i')
     string += 2;
+  else if (startswith (string, "tms320"))
+    string += 6;
   if (*string == 'C' || *string == 'c')
     string++;
   if (*string == '3')
@@ -28,10 +28,12 @@ static bool
 	    const char *string)
 {
-  /* Allow strings of form [ti][Cc][34], let's not be too picky
+  /* Allow strings of form (tms320|ti|)[Cc][34], let's not be too picky
      about strange numbered machines in C3x or C4x series.  */
   if (string[0] == 't' && string[1] == 'i')

-- 
Alan Modra


More information about the Binutils mailing list